@@ -9,20 +9,20 @@
 #  ifndef POLKITQT1_CORE_EXPORT
 #    ifdef polkit_qt5_core_1_EXPORTS
         /* We are building this library */
-#      define POLKITQT1_CORE_EXPORT 
+#      define POLKITQT1_CORE_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define POLKITQT1_CORE_EXPORT 
+#      define POLKITQT1_CORE_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef POLKITQT1_CORE_NO_EXPORT
-#    define POLKITQT1_CORE_NO_EXPORT 
+#    define POLKITQT1_CORE_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
 #ifndef POLKITQT1_CORE_DEPRECATED
-#  define POLKITQT1_CORE_DEPRECATED 
+#  define POLKITQT1_CORE_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
 #ifndef POLKITQT1_CORE_DEPRECATED_EXPORT
@@ -33,6 +33,7 @@
 #  define POLKITQT1_CORE_DEPRECATED_NO_EXPORT POLKITQT1_CORE_NO_EXPORT POLKITQT1_CORE_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef POLKITQT1_CORE_NO_DEPRECATED
 #    define POLKITQT1_CORE_NO_DEPRECATED
